@@ -47,7 +47,7 @@ class DialogHelp(wx.Dialog):
 		self.Bind(wx.EVT_MENU, self.Escape, id=ID_ESC)
 		
 		dbox = wx.BoxSizer(wx.VERTICAL)
-		btn = wx.Button(self, wx.ID_OK)
+		btn = wx.Button(self, wx.ID_CANCEL)
 		btn.SetDefault()
 		win = TestHtmlPanel(self, size = kwds["size"]) 
 		dbox.Add(win, 1, wx.EXPAND)
@@ -58,6 +58,10 @@ class DialogHelp(wx.Dialog):
 		#dbox.Fit(self)
 		#self.Layout()
 		win.SetFocus()# magically enables ESC key too! Go figure :)
+		self.SetTitle(_("Fonty Python Help! Help! I'm being oppressed!"))
+		_icon = wx.EmptyIcon()
+		_icon.CopyFromBitmap(wx.Bitmap(fpsys.mythingsdir + 'fplogo.png', wx.BITMAP_TYPE_ANY))
+		self.SetIcon(_icon)
 	def Escape(self, event):
 		self.Close()
 
@@ -65,8 +69,16 @@ class TestHtmlPanel(wx.Panel):
 	def __init__(self, parent, size):
 		wx.Panel.__init__(self, parent, -1, style=wx.NO_FULL_REPAINT_ON_RESIZE)
 		self.html = MyHtmlWindow(self, -1, size)
-		self.box = wx.BoxSizer(wx.HORIZONTAL)
+		self.box = wx.BoxSizer(wx.VERTICAL)
 		self.box.Add(self.html, 1, wx.GROW)
+
+		#A BACK button. I used internal 'top' links instead
+		#subbox = wx.BoxSizer(wx.HORIZONTAL)
+		#btn = wx.Button(self, wx.ID_BACKWARD)
+		#self.Bind(wx.EVT_BUTTON ,self.OnBack, btn)
+		#subbox.Add(btn, 1, wx.GROW | wx.ALL, 2)
+		#self.box.Add(subbox, 0, wx.GROW)
+
 		self.SetSizer(self.box)
 		self.SetAutoLayout(True)
 		
@@ -78,7 +90,8 @@ class TestHtmlPanel(wx.Panel):
 		self.html.LoadPage( helppaf )
 
 		self.box.Fit(self)
-
+	#def OnBack( self, e ):
+		#self.html.HistoryBack()
 
 class MyHtmlWindow(html.HtmlWindow):
 	def __init__(self, parent, id, size):
@@ -258,7 +271,7 @@ class SegfaultDialog(wx.Dialog):
 		self.ohDear.SetFont( font )
 		
 
-		self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below. Please use the Check Fonts tool in Fonty\n(from the command-line or the File menu) to go through this directory and mark all the dangerous fonts.\n(You could simply move this font elsewhere, but others may remain to cause trouble.)\n" ))
+		self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below. Please use the Check Fonts tool in Fonty\n(from the command-line or the Tools menu) to go through this directory and mark all the dangerous fonts.\n(You could simply move this font elsewhere, but others may remain to cause trouble.)\n" ))
 
 		font = wx.Font(11, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
 		self.culprit = wx.StaticText( self, -1, culprit ) 
@@ -284,6 +297,36 @@ class SegfaultDialog(wx.Dialog):
 		box.Fit(self)
 		self.Layout()
 		
+class LocateDirectory(wx.Dialog):
+	"""
+	Sep 2009 : A nicer (than std dir dialogue) dialogue for locating a directory.
+	It starts in the cwd.
+	"""
+	def __init__(self, parent):
+		wx.Dialog.__init__(self, parent, -1, title = _("Locate a directory for the zip file(s)."),
+				pos=wx.DefaultPosition,style=wx.DEFAULT_FRAME_STYLE)
+
+		sizer = wx.BoxSizer(wx.VERTICAL)
+		self.treedir = wx.GenericDirCtrl( self, -1, dir=os.getcwd(), style=wx.DIRCTRL_DIR_ONLY )
+
+		btno = wx.Button(self, wx.ID_OK)
+		btnc = wx.Button(self, wx.ID_CANCEL)
+
+		sizer.Add(self.treedir, 1, wx.EXPAND)
+		sizer.Add(btno, 0, wx.EXPAND)
+		sizer.Add(btnc, 0, wx.EXPAND)
+
+		btnsizer = wx.StdDialogButtonSizer()
+		btno.SetDefault()
+		btnsizer.AddButton(btno)
+		btnsizer.AddButton(btnc)
+		btnsizer.Realize()
+
+		self.SetSizer(sizer)
+		self.SetAutoLayout(True)
+
+	def GetPath(self):
+		return self.treedir.GetPath()
 
 class DialogCheckFonts( wx.Dialog ):
 	"""
@@ -297,7 +340,10 @@ class DialogCheckFonts( wx.Dialog ):
 		
 		## LEFT
 		leftsz = wx.BoxSizer(wx.VERTICAL)
+
+		font = wx.Font(12, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
 		title = wx.StaticText( self,-1,  _("Choose a directory and double click it to start"))
+		title.SetFont( font )
 		leftsz.Add(title,0,wx.EXPAND | wx.ALL, border=4 )
 		self.treedir = wx.GenericDirCtrl( self, -1, dir=startdir, style=wx.DIRCTRL_DIR_ONLY )
 		leftsz.Add( self.treedir, 1, wx.EXPAND|wx.ALL)
@@ -308,13 +354,16 @@ class DialogCheckFonts( wx.Dialog ):
 		size=(200,-1), style = wx.TE_MULTILINE | wx.TE_READONLY )
 		rightsz.Add(self.output,1,wx.EXPAND | wx.ALL)
 
-		btnsizer = wx.StdDialogButtonSizer()
-		btn = wx.Button(self, wx.ID_OK)
-		btn.SetDefault()
-		btnsizer.AddButton(btn)
-		btnsizer.Realize()
-		
-		rightsz.Add(btn,0,wx.EXPAND)
+		## Because I want a CLOSE button -- I have to do all the button
+		## stuff manually. StdDialogButtonSizer only provides certain buttons
+		## that are not appropriate for this form.
+		bsz = wx.BoxSizer(wx.HORIZONTAL)
+		self.btn = wx.Button(self, wx.ID_CLOSE)
+		self.btn.SetDefault()
+		bsz.Add(self.btn,1,wx.EXPAND)
+		self.btn.Bind( wx.EVT_BUTTON, self.OnClick)
+
+		rightsz.Add(bsz,0,wx.EXPAND)
 		
 		sz = wx.BoxSizer(wx.HORIZONTAL)
 		
@@ -326,6 +375,8 @@ class DialogCheckFonts( wx.Dialog ):
 		self.tree = self.treedir.GetTreeCtrl()
 
 		self.tree.Bind(wx.EVT_LEFT_DCLICK, self.__goFigure)
+	def OnClick(self,e):
+		self.Close(True)
 
 	def printer( self, txt=None ):
 		if txt is None: txt = "\n"
